@@ -127,7 +127,7 @@ class NetworkTestBase(unittest.TestCase):
         # systemd, as it  will change the initial MAC address after the device
         # was created and networkd took control. Give it some time, so we read
         # the correct MAC address
-        time.sleep(0.1)
+        time.sleep(1)
         with open("/sys/class/net/%s/address" % klass.dev_w_ap) as f:
             klass.mac_w_ap = f.read().strip().upper()
         with open("/sys/class/net/%s/address" % klass.dev_w_client) as f:
@@ -424,3 +424,9 @@ def run_in_subprocess(fn):
         args[0].wrap_process(fn, *args, **kwargs)
 
     return wrapped
+
+def wait_nm_online():
+    tries = 5
+    while tries > 0 and subprocess.call(['nm-online', '-qs']) != 0:
+        time.sleep(1)
+        tries = tries - 1
